==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/GetLinkerPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.GetLinkerPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property linkerName The name Linker resource.
 * @property resourceUri The fully qualified Azure Resource manager identifier of the resource to be connected.
 */
public data class GetLinkerPlainArgs(
    public val linkerName: String,
    public val resourceUri: String,
) : ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.GetLinkerPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.servicelinker.inputs.GetLinkerPlainArgs =
        com.pulumi.azurenative.servicelinker.inputs.GetLinkerPlainArgs.builder()
            .linkerName(linkerName.let({ args0 -> args0 }))
            .resourceUri(resourceUri.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetLinkerPlainArgs].
 */
@PulumiTagMarker
public class GetLinkerPlainArgsBuilder internal constructor() {
    private var linkerName: String? = null

    private var resourceUri: String? = null

    /**
     * @param value The name Linker resource.
     */
    @JvmName("nhqnxdcxpytyvlon")
    public suspend fun linkerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.linkerName = mapped
    }

    /**
     * @param value The fully qualified Azure Resource manager identifier of the resource to be connected.
     */
    @JvmName("btfagcgbujfvtjen")
    public suspend fun resourceUri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceUri = mapped
    }

    internal fun build(): GetLinkerPlainArgs = GetLinkerPlainArgs(
        linkerName = linkerName ?: throw PulumiNullFieldException("linkerName"),
        resourceUri = resourceUri ?: throw PulumiNullFieldException("resourceUri"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/servicelinker/kotlin/inputs/GetLinkerPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicelinker.kotlin.inputs

import com.pulumi.azurenative.servicelinker.inputs.GetLinkerPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property linkerName The name Linker resource.
 * @property resourceUri The fully qualified Azure Resource manager identifier of the resource to be connected.
 */
public data class GetLinkerPlainArgs(
    public val linkerName: String,
    public val resourceUri: String,
) : ConvertibleToJava<com.pulumi.azurenative.servicelinker.inputs.GetLinkerPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.servicelinker.inputs.GetLinkerPlainArgs =
        com.pulumi.azurenative.servicelinker.inputs.GetLinkerPlainArgs.builder()
            .linkerName(linkerName.let({ args0 -> args0 }))
            .resourceUri(resourceUri.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetLinkerPlainArgs].
 */
@PulumiTagMarker
public class GetLinkerPlainArgsBuilder internal constructor() {
    private var linkerName: String? = null

    private var resourceUri: String? = null

    /**
     * @param value The name Linker resource.
     */
    @JvmName("sdunfmyurwrpospp")
    public suspend fun linkerName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.linkerName = mapped
    }

    /**
     * @param value The fully qualified Azure Resource manager identifier of the resource to be connected.
     */
    @JvmName("upesgwthipvjwbrw")
    public suspend fun resourceUri(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceUri = mapped
    }

    internal fun build(): GetLinkerPlainArgs = GetLinkerPlainArgs(
        linkerName = linkerName ?: throw PulumiNullFieldException("linkerName"),
        resourceUri = resourceUri ?: throw PulumiNullFieldException("resourceUri"),
    )
}
